PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/Pusher.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
Pusher.hpp
1#ifndef GYM_PCB_UTIL_PUSHER_H
2#define GYM_PCB_UTIL_PUSHER_H
3
4// How it works ...
5// ...
6//
7
8class PCBoard;
9class Connection;
10
11 class Pusher
12{
13public:
14 Pusher(PCBoard&);
15 ~Pusher();
16
17 bool route(Connection&);
18
19private:
20 void init(Connection&);
21
22private:
23 PCBoard &mPCB;
24 Connection *mConnection;
25};
26
27#endif // GYM_PCB_UTIL_PUSHER_H
Connection
Definition Connection.hpp:17
PCBoard
Definition PCBoard.hpp:36